AndroidWebViewConfiguration class
Constructors
- AndroidWebViewConfiguration({bool enableSlowWholeDocumentDraw = true, bool useWideViewPort = true, bool loadWithOverviewMode = true, bool setSupportZoom = true, bool builtInZoomControls = true, bool displayZoomControls = false, AndroidWebViewLayoutAlgorithm layoutAlgorithm = AndroidWebViewLayoutAlgorithm.normal})
-
const
Properties
- builtInZoomControls → bool
-
final
- displayZoomControls → bool
-
final
- enableSlowWholeDocumentDraw → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layoutAlgorithm → AndroidWebViewLayoutAlgorithm
-
final
- loadWithOverviewMode → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setSupportZoom → bool
-
final
- useWideViewPort → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited